salmon package
==============

Subpackages
-----------

.. toctree::

    salmon.handlers

Submodules
----------

.. toctree::

   salmon.bounce
   salmon.commands
   salmon.confirm
   salmon.encoding
   salmon.mail
   salmon.queue
   salmon.routing
   salmon.server
   salmon.testing
   salmon.utils
   salmon.view

Module contents
---------------

.. automodule:: salmon
    :members:
    :undoc-members:
    :show-inheritance:
